/*-------------------------------------------------------- 
* Module Name : transport gateway api
* Version : 1.4.1
* 
* Software Name : Transport Manager
* Version : 1.4.1
*
* Copyright © 01-10-2012 – 01-10-2012 France Télécom
* This software is distributed under the Apache (v2) license,
* the text of which is available at http://www.apache.org/licenses/LICENSE-2.0.html
* or see the "license.txt" file for more details.
*
*--------------------------------------------------------
* File Name   : ${file_name}
*
* Created     : ${date}
* Author(s)   : ${authors}
*
* Description :
* Transport gateway api to plug any SMS broker behind.
*
*--------------------------------------------------------
* ${Log}
*
*/



package com.orange.labs.quickpass.tm.gateway;

import com.orange.labs.quickpass.type.Msisdn;

/**
 * SMS Gateway adapter interface. 
 * This interface shall be implemented to connect to a specific SMS broker
 */
public interface SMSGatewayAdapter {

    /**
     * Generic send text SMS function
     * @param msg msg to send
     * @param msisdn msisdn
     */
    void sendTextSMS(Msisdn msisdn, String msg);

    /**
     * Generic send wap push SMS function
     * @param msisdn msisdn
     * @param url url
     * @param msg msg
     */
    void sendPushWAPSMS(Msisdn msisdn, String url, String msg);

    /**
     * Generic send push SMS function
     * @param msg msg
     * @param msisdn msisdn
     * @param port port
     */
    void sendPushSMS(Msisdn msisdn, String msg,int port);

    /**
     * Generic send binary SMS function 
     * @param data secured packet following ETSI 102.225
     * @param msisdn msisdn
     */
    void sendBinarySMS(Msisdn msisdn, byte[] data);
   

}
